Class: Mercenary::Presenter

Inherits:
Object
  • Object
show all
Defined in:
lib/mercenary/presenter.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(command) ⇒ Presenter

Public: Make a new Presenter

command - a Mercenary::Command to present

Returns nothing



12
13
14
# File 'lib/mercenary/presenter.rb', line 12

def initialize(command)
  @command = command
end

Dynamic Method Handling

This class handles dynamic methods through the method_missing method

#method_missing(meth, *args, &block) ⇒ Object

Public: Turn a print_* into a *_presentation or freak out

meth - the method being called args - an array of arguments passed to the missing method block - the block passed to the missing method

Returns the value of whatever function is called



93
94
95
96
97
98
99
100
101
# File 'lib/mercenary/presenter.rb', line 93

def method_missing(meth, *args, &block)
  if meth.to_s =~ %r!^print_(.+)$!
    send("#{Regexp.last_match(1).downcase}_presentation")
  else
    # You *must* call super if you don't handle the method,
    # otherwise you'll mess up Ruby's method lookup.
    super
  end
end

Instance Attribute Details

#commandObject

Returns the value of attribute command.



5
6
7
# File 'lib/mercenary/presenter.rb', line 5

def command
  @command
end

Instance Method Details

#command_headerObject

Public: Builds the command header, including the command identity and description

Returns the command header as a String



62
63
64
65
66
# File 'lib/mercenary/presenter.rb', line 62

def command_header
  header = command.identity.to_s
  header << " -- #{command.description}" if command.description
  header
end

#command_options_presentationObject



32
33
34
35
36
37
38
# File 'lib/mercenary/presenter.rb', line 32

def command_options_presentation
  return nil if command.options.empty?

  options = command.options
  options -= command.parent.options if command.parent
  options.map(&:to_s).join("\n")
end

#command_presentationObject

Public: Builds a string representation of the whole command

Returns the string representation of the whole command



71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/mercenary/presenter.rb', line 71

def command_presentation
  msg = []
  msg << command_header
  msg << "Usage:"
  msg << usage_presentation

  if opts = options_presentation
    msg << "Options:\n#{opts}"
  end
  if subcommands = subcommands_presentation
    msg << "Subcommands:\n#{subcommands_presentation}"
  end
  msg.join("\n\n")
end

#options_presentationObject

Public: Builds a string representation of the options

Returns the string representation of the options



26
27
28
29
30
# File 'lib/mercenary/presenter.rb', line 26

def options_presentation
  return nil unless command_options_presentation || parent_command_options_presentation

  [command_options_presentation, parent_command_options_presentation].compact.join("\n")
end

#parent_command_options_presentationObject

Public: Builds a string representation of the options for parent commands

Returns the string representation of the options for parent commands



44
45
46
47
48
# File 'lib/mercenary/presenter.rb', line 44

def parent_command_options_presentation
  return nil unless command.parent

  Presenter.new(command.parent).options_presentation
end

#subcommands_presentationObject

Public: Builds a string representation of the subcommands

Returns the string representation of the subcommands



53
54
55
56
57
# File 'lib/mercenary/presenter.rb', line 53

def subcommands_presentation
  return nil if command.commands.empty?

  command.commands.values.uniq.map(&:summarize).join("\n")
end

#usage_presentationObject

Public: Builds a string representation of the command usage

Returns the string representation of the command usage



19
20
21
# File 'lib/mercenary/presenter.rb', line 19

def usage_presentation
  "  #{command.syntax}"
end